@@ -21,6 +21,7 @@ File utilities.
 
 import contextlib
 import errno
+import hashlib
 import os
 import stat
 import tempfile
@@ -103,3 +104,23 @@ def write_to_tempfile(content, path=None, suffix='', prefix='tmp'):
     finally:
         os.close(fd)
     return path
+
+
+def compute_file_checksum(path, read_chunksize=65536, algorithm='sha256'):
+    """Compute checksum of a file's contents.
+
+    :param path: Path to the file
+    :param read_chunksize: Maximum number of bytes to be read from the file
+     at once. Default is 65536 bytes or 64KB
+    :param algorithm: The hash algorithm name to use. For example, 'md5',
+     'sha256', 'sha512' and so on. Default is 'sha256'. Refer to
+     hashlib.algorithms_available for available algorithms
+    :return: Hex digest string of the checksum
+
+    .. versionadded:: 3.31.0
+    """
+    checksum = hashlib.new(algorithm)  # Raises appropriate exceptions.
+    with open(path, 'rb') as f:
+        for chunk in iter(lambda: f.read(read_chunksize), b''):
+            checksum.update(chunk)
+    return checksum.hexdigest()
